==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/RenameKeyTransformBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RenameKeyTransformBuilder extends RenameKeyTransformFluentImpl<RenameKeyTransformBuilder> implements VisitableBuilder<RenameKeyTransform,RenameKeyTransformBuilder>{
  public RenameKeyTransformBuilder() {
    this(false);
  }
  public RenameKeyTransformBuilder(Boolean validationEnabled) {
    this(new RenameKeyTransform(), validationEnabled);
  }
  public RenameKeyTransformBuilder(RenameKeyTransformFluent<?> fluent) {
    this(fluent, false);
  }
  public RenameKeyTransformBuilder(RenameKeyTransformFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RenameKeyTransform(), validationEnabled);
  }
  public RenameKeyTransformBuilder(RenameKeyTransformFluent<?> fluent,RenameKeyTransform instance) {
    this(fluent, instance, false);
  }
  public RenameKeyTransformBuilder(RenameKeyTransformFluent<?> fluent,RenameKeyTransform instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RenameKeyTransformBuilder(RenameKeyTransform instance) {
    this(instance,false);
  }
  public RenameKeyTransformBuilder(RenameKeyTransform instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  RenameKeyTransformFluent<?> fluent;
  Boolean validationEnabled;
  public RenameKeyTransform build() {
    RenameKeyTransform buildable = new RenameKeyTransform(fluent.getFrom(),fluent.getTo());
    return buildable;
  }
  
}

==> servicecatalog-model-6.8.1-sources.jar: io/fabric8/servicecatalog/api/model/RenameKeyTransformBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RenameKeyTransformBuilder extends RenameKeyTransformFluent<RenameKeyTransformBuilder> implements VisitableBuilder<RenameKeyTransform,RenameKeyTransformBuilder>{
  public RenameKeyTransformBuilder() {
    this(false);
  }
  public RenameKeyTransformBuilder(Boolean validationEnabled) {
    this(new RenameKeyTransform(), validationEnabled);
  }
  public RenameKeyTransformBuilder(RenameKeyTransformFluent<?> fluent) {
    this(fluent, false);
  }
  public RenameKeyTransformBuilder(RenameKeyTransformFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RenameKeyTransform(), validationEnabled);
  }
  public RenameKeyTransformBuilder(RenameKeyTransformFluent<?> fluent,RenameKeyTransform instance) {
    this(fluent, instance, false);
  }
  public RenameKeyTransformBuilder(RenameKeyTransformFluent<?> fluent,RenameKeyTransform instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new RenameKeyTransform());

    if (instance != null) {
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RenameKeyTransformBuilder(RenameKeyTransform instance) {
    this(instance,false);
  }
  public RenameKeyTransformBuilder(RenameKeyTransform instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new RenameKeyTransform());

    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  RenameKeyTransformFluent<?> fluent;
  Boolean validationEnabled;
  public RenameKeyTransform build() {
    RenameKeyTransform buildable = new RenameKeyTransform(fluent.getFrom(),fluent.getTo());
    return buildable;
  }
  
}
